@@ -289,15 +289,20 @@ bool PerformanceConfigHipImplicitGemmGroupWrwXdlops::ModelApplyToken(
             idx += 2;
         if(((idx == 15 && (heuristic_kernels[heuristic_indexes[0]].size() == 15)) || idx == 18))
         {
+            if(!std::all_of(value.begin(), value.end(), ::isdigit))
+                return false;
             kernel_id          = valid_kernels[heuristic_indexes[0]] + "+" + value;
             index              = heuristic_indexes[0];
             bool valid_split_k = false;
+            // if `value` is not a valid split_k value, the following warning is raised
+            //   Warning: Workspace for DeviceGroupedConvBwdWeightTwoStage_Xdl_CShuffle::Argument
+            //   is not allocated, use SetWorkSpacePointer.
             switch(problem.GetInDataType())
             {
             case miopenHalf: valid_split_k = CheckIsSupportCKArgs<ck::half_t>(problem); break;
             case miopenFloat: valid_split_k = CheckIsSupportCKArgs<float>(problem); break;
             case miopenInt8:
-            case miopenBFloat16:
+            case miopenBFloat16: valid_split_k = CheckIsSupportCKArgs<ck::bhalf_t>(problem); break;
             case miopenInt64:
             case miopenInt32:
             case miopenFloat8:
@@ -354,14 +359,22 @@ static std::vector<float> GetFeatures(const ProblemDescription& problem, const s
         features[17 * n + 17] = problem.GetGroupCount();
         return features;
     }
+
+    const bool isFwd = problem.GetDirection() == miopen::conv::Direction::Forward;
+    float precision  = 2.0; // miopenHalf
+    if(problem.GetInDataType() == miopenFloat)
+        precision = 3.0;
+    else if(problem.GetInDataType() == miopenBFloat16)
+        precision = 1.0;
+
     std::size_t n = 17; // takes 17 convolution parameters as inputs
     std::vector<float> features(n * n, 0.0f);
-    features[0]           = problem.GetOutChannels();
-    features[n + 1]       = problem.GetOutHeight();
-    features[2 * n + 2]   = problem.GetOutWidth();
-    features[3 * n + 3]   = problem.GetInChannels();
-    features[4 * n + 4]   = problem.GetInHeight();
-    features[5 * n + 5]   = problem.GetInWidth();
+    features[0]           = isFwd ? problem.GetInChannels() : problem.GetOutChannels();
+    features[n + 1]       = isFwd ? problem.GetInHeight() : problem.GetOutHeight();
+    features[2 * n + 2]   = isFwd ? problem.GetInWidth() : problem.GetOutWidth();
+    features[3 * n + 3]   = isFwd ? problem.GetOutChannels() : problem.GetInChannels();
+    features[4 * n + 4]   = isFwd ? problem.GetOutHeight() : problem.GetInHeight();
+    features[5 * n + 5]   = isFwd ? problem.GetOutWidth() : problem.GetInWidth();
     features[6 * n + 6]   = problem.GetWeightsHeight();
     features[7 * n + 7]   = problem.GetWeightsWidth();
     features[8 * n + 8]   = problem.GetPadH();
@@ -371,7 +384,7 @@ static std::vector<float> GetFeatures(const ProblemDescription& problem, const s
     features[12 * n + 12] = problem.GetDilationH();
     features[13 * n + 13] = problem.GetDilationW();
     features[14 * n + 14] = problem.GetBatchSize();
-    features[15 * n + 15] = problem.GetInDataType() == miopenFloat ? 2.0 : 1.0;
+    features[15 * n + 15] = precision;
     features[16 * n + 16] = problem.GetGroupCount();
     return features;
 }
@@ -411,7 +424,8 @@ bool PerformanceConfigHipImplicitGemmGroupWrwXdlops::IsModelApplicable(
 {
     if(ctx.GetStream().GetDeviceName() != "gfx90a" && ctx.GetStream().GetDeviceName() != "gfx942")
         return false;
-    if(problem.GetInDataType() != miopenFloat && problem.GetInDataType() != miopenHalf)
+    if(problem.GetInDataType() != miopenFloat && problem.GetInDataType() != miopenHalf &&
+       problem.GetInDataType() != miopenBFloat16)
         return false;
     if(env::disabled(MIOPEN_DEBUG_GROUP_CONV_IMPLICIT_GEMM_HIP_WRW_XDLOPS_AI_HEUR))
         return false;
@@ -435,6 +449,11 @@ void PerformanceConfigHipImplicitGemmGroupWrwXdlops::HeuristicInit(
             if(RunParameterPredictionModel<float>(ctx, problem))
                 return;
         }
+        else if(problem.GetInDataType() == miopenBFloat16)
+        {
+            if(RunParameterPredictionModel<ck::bhalf_t>(ctx, problem))
+                return;
+        }
         else
         {
             if(RunParameterPredictionModel<ck::half_t>(ctx, problem))
@@ -568,7 +587,7 @@ bool ConvHipImplicitGemmGroupWrwXdlops::IsApplicable(
 #if MIOPEN_BACKEND_HIP && MIOPEN_USE_COMPOSABLEKERNEL
     if(env::disabled(MIOPEN_DEBUG_GROUP_CONV_IMPLICIT_GEMM_HIP_WRW_XDLOPS))
         return false;
-    if(env::enabled(MIOPEN_DEBUG_CONVOLUTION_DETERMINISTIC))
+    if(problem.GetConv().attribute.deterministic)
         return false;
     if(problem.HasMixedDataTypes())
         return false;
@@ -590,7 +609,9 @@ bool ConvHipImplicitGemmGroupWrwXdlops::IsApplicable(
     case miopenHalf: return CheckCKApplicability<ck::half_t>(problem);
     case miopenFloat: return CheckCKApplicability<float>(problem);
     case miopenInt8: return CheckCKApplicability<int8_t>(problem);
-    case miopenBFloat16: return CheckCKApplicability<ck::bhalf_t>(problem);
+    case miopenBFloat16:
+        return StartsWith(ctx.GetStream().GetDeviceName(), "gfx94") &&
+               CheckCKApplicability<ck::bhalf_t>(problem);
     case miopenInt64:
     case miopenInt32:
     case miopenFloat8:
